@@ -1,7 +1,7 @@
 """
 to define db queries for different sql dialect
 """
-from models import DBConnection
+from .models import DBConnection
 # to get db connection
 # read the db configs from the command line
 class QueryInterface:
